@@ -15,7 +15,7 @@ ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.51'
+__version__ = '0.1.54'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -47,6 +47,9 @@ __info__ = {
     '2022/09/06: 0.1.50 加入 crypto 模組',
     '2022/10/23: 0.1.51 get_all_stock_code_name_dict() 加入 _api 參數',
     '2022/10/25: 0.1.52 price_ticks_offset_AB_dec() 還有其他改成Decimal',
+    '2022/10/30: 0.1.53 price_ticks_offsets_dec()',
+    '2022/11/24: 0.1.54 修正一個 redis 非常奇怪的問題'
+
 }
 
 request_headers = {
@@ -472,6 +475,20 @@ def get_ticks_between_dec(_price1: Decimal, _price2: Decimal):
     return ticks
 
 
+def price_ticks_offsets_dec(price: Decimal, ticks, bool_down=False):
+    if isinstance(price, int) or isinstance(price, float):
+        price = Decimal(str(price))
+    list_prices = [price]
+    for i in range(ticks):
+        if bool_down:
+            price -= get_current_price_tick_dec(price, down=bool_down)
+        else:
+            price += get_current_price_tick_dec(price, down=bool_down)
+        list_prices.append(price)
+    return list_prices
+
+
+
 
 def price_ticks_offset_AB_dec(price: Decimal, ticks):
     if isinstance(price, int) or isinstance(price, float):
@@ -823,6 +840,10 @@ if __name__ == '__main__':
     from time import sleep
 
     if True:
+        print(price_ticks_offsets_dec(99, 6))
+        print(price_ticks_offsets_dec(99, 6, True))
+
+    if False:
         print(100.5, 1, price_ticks_offset_dec(100.5, 1))
         print(100.5, -1, price_ticks_offset_dec(100.5, -1))
         print(100, 1, price_ticks_offset_dec(100, 1))
